==> v6.0-preview1.tar.gz: ilspy/ILSpy.BamlDecompiler/Xaml/NamespaceMap.cs <==
﻿/*
	Copyright (c) 2015 Ki

	Permission is hereby granted, free of charge, to any person obtaining a copy
	of this software and associated documentation files (the "Software"), to deal
	in the Software without restriction, including without limitation the rights
	to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
	copies of the Software, and to permit persons to whom the Software is
	furnished to do so, subject to the following conditions:

	The above copyright notice and this permission notice shall be included in
	all copies or substantial portions of the Software.

	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
	IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
	FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
	AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
	LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
	OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
	THE SOFTWARE.
*/

using System;
using ICSharpCode.Decompiler.Metadata;
using ICSharpCode.Decompiler.TypeSystem;

namespace ILSpy.BamlDecompiler.Xaml {
	internal class NamespaceMap {
		public string XmlnsPrefix { get; set; }
		public string FullAssemblyName { get; set; }
		public string XMLNamespace { get; set; }
		public string CLRNamespace { get; set; }

		public NamespaceMap(string prefix, string fullAssemblyName, string xmlNs)
			: this(prefix, fullAssemblyName, xmlNs, null) {
		}

		public NamespaceMap(string prefix, string fullAssemblyName, string xmlNs, string clrNs) {
			XmlnsPrefix = prefix;
			FullAssemblyName = fullAssemblyName;
			XMLNamespace = xmlNs;
			CLRNamespace = clrNs;
		}

		public override string ToString() => $"{XmlnsPrefix}:[{FullAssemblyName}|{CLRNamespace ?? XMLNamespace}]";
	}
}

==> v6.2-preview1.tar.gz: ilspy/ILSpy.BamlDecompiler/Xaml/NamespaceMap.cs <==
﻿/*
	Copyright (c) 2015 Ki

	Permission is hereby granted, free of charge, to any person obtaining a copy
	of this software and associated documentation files (the "Software"), to deal
	in the Software without restriction, including without limitation the rights
	to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
	copies of the Software, and to permit persons to whom the Software is
	furnished to do so, subject to the following conditions:

	The above copyright notice and this permission notice shall be included in
	all copies or substantial portions of the Software.

	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
	IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
	FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
	AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
	LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
	OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
	THE SOFTWARE.
*/

using System;

using ICSharpCode.Decompiler.Metadata;
using ICSharpCode.Decompiler.TypeSystem;

namespace ILSpy.BamlDecompiler.Xaml
{
	internal class NamespaceMap
	{
		public string XmlnsPrefix { get; set; }
		public string FullAssemblyName { get; set; }
		public string XMLNamespace { get; set; }
		public string CLRNamespace { get; set; }

		public NamespaceMap(string prefix, string fullAssemblyName, string xmlNs)
			: this(prefix, fullAssemblyName, xmlNs, null)
		{
		}

		public NamespaceMap(string prefix, string fullAssemblyName, string xmlNs, string clrNs)
		{
			XmlnsPrefix = prefix;
			FullAssemblyName = fullAssemblyName;
			XMLNamespace = xmlNs;
			CLRNamespace = clrNs;
		}

		public override string ToString() => $"{XmlnsPrefix}:[{FullAssemblyName}|{CLRNamespace ?? XMLNamespace}]";
	}
}
